<?php

namespace Drupal\wsm\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceFormatterBase;
use Drupal\wsm\Controller\EndpointController;

/**
 * Plugin implementation of the 'entity reference ID' formatter.
 *
 * @FieldFormatter(
 *   id = "wsm_endpoint",
 *   label = @Translation("WebService Enpoint"),
 *   description = @Translation("WebService Endpoint formatter with API call"),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class WebServiceManagerEndpointFormatter extends EntityReferenceFormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      // Call to the API.
      try {
        $entity_controller = new EndpointController();
        $api_res_array = $entity_controller->endpointCall($entity);
        // Render content.
        $elements[$delta] = [
          '#theme' => 'endpoint_reference_formatter',
          '#fields' => $api_res_array,
        ];
      }
      catch (\Exception $exception) {
        $elements[$delta] = [
          '#theme' => 'endpoint_reference_formatter',
          '#fields' => [],
        ];
      }
    }

    return $elements;
  }

}
